==> quickcapture-0.0.8.tar.gz: README.md <==

# quickcapture
<img  class="img-fluid"  align="center"  src="https://github.com/ExtrieveTechnologies/QuickCapture/blob/main/QuickCapture.png?raw=true"  width="30%"  alt="img-verification"><a  align="center"  href='https://play.google.com/store/apps/details?id=com.extrieve.exScan&pcampaignid=pcampaignidMKT-Other-global-all-co-prtnr-py-PartBadge-Mar2515-1'  title="Click to download android app"  target="_blank"  rel="noopener noreferrer"><img  align="center"  width="150px"  alt='Get it on Google Play'  src='https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png'/></a>


Flutter plugin QuickCapture makes it possible to scan documents using mobile devices.

With the simple integration of this plugin, mobile applications can reliably scan documents using the camera on a user's mobile device. High-quality documents are captured with optimised focus control.

  

> It's not "**just**" a scanning SDK. It's a "**document**" scanning/capture SDK evolved with **Best Quality**, **Highest Possible Compression**, **Image Optimisation**, of output document in mind.

  

> Control **DPI**,**Layout** & **Size** of output images, PDF & TIFF

  

>  **Developer-friendly** & **Easy to integration** SDK.

  

Documents can be compressed,optimised & converted to make them smaller, which speeds up uploads and uses less infrastructure.

  

Also can build PDF and TIFF output from the captured images or even convert images to PDF and TIFF.

  

For more information : [Checkout](https://www.extrieve.com/mobile-document-scanning/)

  

Compatibility

-------------

  

*  **JAVA 8 Support**: Requires JAVA version 8 support for the application.

*  **Minimum Android SDK**: Requires a minimum API level of 21.

*  **Compiled SDK Version**: compiled against **API 33**.

  

*  **Minimum IOS**: requires a minimum iOS 11.

  
  

### Other available platform options

- [Android - Native](https://github.com/ExtrieveTechnologies/QuickCapture_Android)

- [iOS - Native](https://github.com/ExtrieveTechnologies/QuickCapture_IOS)

  
  

## [0.0.8] - 2023-08-09

### Updates

- Added support for IOS - from SDK 2.0.0.7

- Added latest android fixes from SDK v3.0.7.

- Bug fixes and other performance improvements.
  

## Getting Started

For help getting started with Flutter development, view the

[online documentation](https://flutter.dev/docs), which offers tutorials,

samples, guidance on mobile development, and a full API reference.

  
  

[© 1996 - 2023 Extrieve Technologies](https://www.extrieve.com/)

==> quickcapture-0.0.9.tar.gz: README.md <==

# quickcapture
<img  class="img-fluid"  align="center"  src="https://github.com/ExtrieveTechnologies/QuickCapture/blob/main/QuickCapture.png?raw=true"  width="30%"  alt="img-verification"><a  align="center"  href='https://play.google.com/store/apps/details?id=com.extrieve.exScan&pcampaignid=pcampaignidMKT-Other-global-all-co-prtnr-py-PartBadge-Mar2515-1'  title="Click to download android app"  target="_blank"  rel="noopener noreferrer"><img  align="center"  width="150px"  alt='Get it on Google Play'  src='https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png'/></a>


An enterprise-grade Flutter plugin for document scanning and capture, compatible with both Android and iOS platforms. This plugin offers:

- Document Scanning: Efficiently scan documents directly within the app.
- AI-Powered Capture: Utilize artificial intelligence for enhanced capture accuracy.
- Identification: Recognize and categorize documents seamlessly.
- Compression & Optimization: Ensure reduced file sizes without compromising on quality.
- Customizable Output: Control DPI, layout, and size of the resulting images.
- Multiple Format Support: Save and export in JPEG, PDF, and TIFF formats.
- Advanced Focus Control: Guarantee high-quality document captures tailored for enterprise applications.


> It's not "**just**" a scanning SDK. It's a "**document**" scanning/capture SDK evolved with **Best Quality**, **Highest Possible Compression**, **Image Optimisation**, of output document in mind.

> Control **DPI**,**Layout** & **Size** of output images, PDF & TIFF

>  **Developer-friendly** & **Easy to integration** SDK.


Documents can be **compressed,optimised & converted** to make them **smaller**, which speeds up uploads and uses less infrastructure.

Also can build **PDF** and **TIFF** output from the captured images or even convert images to PDF and TIFF.


For more information : [Checkout](https://www.extrieve.com/mobile-document-scanning/)


Compatibility
-------------
  
*  **JAVA 8 Support**: Requires JAVA version 8 support for the application.

*  **Minimum Android SDK**: Requires a minimum API level of 21.

*  **Compiled SDK Version**: compiled against **API 33**.

*  **Minimum IOS**: requires a minimum iOS 11.

  
  
## Other available platform options

- [Android - Native](https://github.com/ExtrieveTechnologies/QuickCapture_Android)

- [iOS - Native](https://github.com/ExtrieveTechnologies/QuickCapture_IOS)

  
  

## [0.0.9] - 2023-08-09

### Updates

* Added Latest IOS SDK v2.0.0.7.
* Sample implementation for same.
* UI updates and other improvements.
  

## Getting Started

For help getting started with Flutter development, view the

[online documentation](https://flutter.dev/docs), which offers tutorials,

samples, guidance on mobile development, and a full API reference.

  

[© 1996 - 2023 Extrieve Technologies](https://www.extrieve.com/)
